@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -56,6 +56,7 @@ import com.openexchange.ajax.requesthandler.AJAXRequestResult;
 import com.openexchange.folder.json.parser.FolderParser;
 import com.openexchange.folder.json.services.ServiceRegistry;
 import com.openexchange.folderstorage.Folder;
+import com.openexchange.folderstorage.FolderResponse;
 import com.openexchange.folderstorage.FolderService;
 import com.openexchange.groupware.AbstractOXException;
 import com.openexchange.tools.servlet.AjaxException;
@@ -103,11 +104,9 @@ public final class CreateAction extends AbstractFolderAction {
          * Create
          */
         final FolderService folderService = ServiceRegistry.getInstance().getService(FolderService.class, true);
-        final String newId = folderService.createFolder(folder, session);
-        /*
-         * Return appropriate result
-         */
-        return new AJAXRequestResult(newId);
+        final FolderResponse<String> newIdResponse = folderService.createFolder(folder, session);
+        final String newId = newIdResponse.getResponse();
+        return new AJAXRequestResult(newId, folderService.getFolder(treeId, newId, session, null).getLastModifiedUTC()).addWarnings(newIdResponse.getWarnings());
     }
 
 }
