@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -49,7 +49,12 @@
 
 package com.openexchange.folder.json.actions;
 
+import java.util.Arrays;
+import java.util.Collections;
 import java.util.Date;
+import java.util.HashSet;
+import java.util.Locale;
+import java.util.Set;
 import org.json.JSONArray;
 import com.openexchange.ajax.AJAXServlet;
 import com.openexchange.ajax.requesthandler.AJAXRequestData;
@@ -59,6 +64,7 @@ import com.openexchange.folder.json.Tools;
 import com.openexchange.folder.json.services.ServiceRegistry;
 import com.openexchange.folder.json.writer.FolderWriter;
 import com.openexchange.folderstorage.ContentType;
+import com.openexchange.folderstorage.FolderExceptionErrorMessage;
 import com.openexchange.folderstorage.FolderResponse;
 import com.openexchange.folderstorage.FolderService;
 import com.openexchange.folderstorage.FolderServiceDecorator;
@@ -99,9 +105,17 @@ public final class ListAction extends AbstractFolderAction {
             throw new AjaxException(AjaxException.Code.MISSING_PARAMETER, "parent");
         }
         final int[] columns = parseIntArrayParameter(AJAXServlet.PARAMETER_COLUMNS, request);
-        final boolean all = Boolean.parseBoolean(request.getParameter(AJAXServlet.PARAMETER_ALL));
+        final boolean all;
+        {
+            final String parameter = request.getParameter(AJAXServlet.PARAMETER_ALL);
+            all = "1".equals(parameter) || Boolean.parseBoolean(parameter);
+        }
         final String timeZoneId = request.getParameter(AJAXServlet.PARAMETER_TIMEZONE);
         final java.util.List<ContentType> allowedContentTypes = parseOptionalContentTypeArrayParameter("allowed_modules", request);
+        boolean errorOnDuplicateName = parseBoolean(request.getParameter("errorOnDuplicateName"), false);
+        if (!errorOnDuplicateName) {
+            errorOnDuplicateName = parseBoolean(request.getParameter("errOnDuplName"), false);
+        }
         /*
          * Request subfolders from folder service
          */
@@ -114,11 +128,42 @@ public final class ListAction extends AbstractFolderAction {
          */
         long lastModified = 0;
         final UserizedFolder[] subfolders = subfoldersResponse.getResponse();
-        for (final UserizedFolder userizedFolder : subfolders) {
-            final Date modified = userizedFolder.getLastModifiedUTC();
-            if (modified != null) {
-                final long time = modified.getTime();
-                lastModified = ((lastModified >= time) ? lastModified : time);
+        final int length = subfolders.length;
+        if (length <= 0) {
+            /*
+             * Return appropriate result
+             */
+            return new AJAXRequestResult(new JSONArray(), null).addWarnings(subfoldersResponse.getWarnings());
+        }
+        /*
+         * length > 0
+         */
+        if (errorOnDuplicateName) {
+            final Set<String> names = new HashSet<String>(length);
+            for (int i = 0; i < length; i++) {
+                final UserizedFolder userizedFolder = subfolders[i];
+                Locale locale = userizedFolder.getLocale();
+                if (null == locale) {
+                    locale = FolderWriter.DEFAULT_LOCALE;
+                }
+                if (!names.add(userizedFolder.getLocalizedName(locale))) {
+                    // Duplicate name
+                    final String parentName = folderService.getFolder(treeId, parentId, session, null).getLocalizedName(locale);
+                    throw FolderExceptionErrorMessage.DUPLICATE_NAME.create(userizedFolder.getLocalizedName(locale), parentName);
+                }
+                final Date modified = userizedFolder.getLastModifiedUTC();
+                if (modified != null) {
+                    final long time = modified.getTime();
+                    lastModified = ((lastModified >= time) ? lastModified : time);
+                }
+            }
+        } else {
+            for (int i = length - 1; i >= 0; i--) {
+                final Date modified = subfolders[i].getLastModifiedUTC();
+                if (modified != null) {
+                    final long time = modified.getTime();
+                    lastModified = ((lastModified >= time) ? lastModified : time);
+                }
             }
         }
         /*
@@ -131,4 +176,13 @@ public final class ListAction extends AbstractFolderAction {
         return new AJAXRequestResult(jsonArray, 0 == lastModified ? null : new Date(lastModified)).addWarnings(subfoldersResponse.getWarnings());
     }
 
+    private static Set<String> TRUES = Collections.unmodifiableSet(new HashSet<String>(Arrays.asList("true", "yes", "on", "1")));
+
+    private static boolean parseBoolean(final String string, final boolean defaultValue) {
+        if (null == string) {
+            return defaultValue;
+        }
+        return TRUES.contains(string.toLowerCase(Locale.ENGLISH).trim());
+    }
+
 }
