@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -65,7 +65,7 @@ import com.openexchange.tools.servlet.AjaxException;
 import com.openexchange.tools.session.ServerSession;
 
 /**
- * {@link UpdateAction} - Maps the action to a UPDATE action.
+ * {@link UpdateAction} - Maps the action to an UPDATE action.
  * 
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
@@ -115,7 +115,8 @@ public final class UpdateAction extends AbstractFolderAction {
         final Folder folder = FolderParser.parseFolder(folderObject);
         folder.setID(id);
         try {
-            if (folderObject.hasAndNotNull(FolderField.SUBSCRIBED.getName()) && 0 == folderObject.getInt(FolderField.SUBSCRIBED.getName())) {
+            final String fieldName = FolderField.SUBSCRIBED.getName();
+            if (folderObject.hasAndNotNull(fieldName) && 0 == folderObject.getInt(fieldName)) {
                 /*
                  * TODO: Remove this ugly hack to fix broken UI behavior which send "subscribed":0 for db folders
                  */
@@ -136,11 +137,10 @@ public final class UpdateAction extends AbstractFolderAction {
         final FolderService folderService = ServiceRegistry.getInstance().getService(FolderService.class, true);
         folderService.updateFolder(folder, timestamp, session);
         /*
-         * Return appropriate result
+         * Invoke folder.getID() to obtain possibly new folder identifier
          */
         final String newId = folder.getID();
-        final Date lastModifiedUTC = folderService.getFolder(treeId, newId, session, null).getLastModifiedUTC();
-        return new AJAXRequestResult(newId, lastModifiedUTC);
+        return new AJAXRequestResult(newId, folderService.getFolder(treeId, newId, session, null).getLastModifiedUTC());
     }
 
 }
